Search the World Bank Documents & Reports archive from the Documents & Reports API.
Usage
wb_document(
search = NULL,
country = NULL,
type = NULL,
project = NULL,
start_date = NULL,
end_date = NULL,
id = NULL
)Arguments
- search
(
NULL|character(1))
Free-text search term. DefaultNULL.- country
(
NULL|character())
Two-character World Bank country code(s) to filter by, e.g."BR"orc("BR", "IN"). Matching is case insensitive, and documents for any of the given codes are returned. DefaultNULL.- type
(
NULL|character())
Document type(s) to filter by, e.g."Report"or"Project Appraisal Document". Documents of any of the given types are returned. DefaultNULL.- project
(
NULL|character())
Project ID(s) to filter by, e.g."P180429". Documents for any of the given projects are returned. DefaultNULL.- start_date
(
NULL|character(1))
Document start date in"YYYY-MM-DD"format. DefaultNULL.- end_date
(
NULL|character(1))
Document end date in"YYYY-MM-DD"format. DefaultNULL.- id
(
NULL|character())
Document ID(s) to filter by, as returned in theidcolumn. DefaultNULL.
Value
A data.frame() with World Bank document data. The columns are:
id: The document ID.title: The document title.type: The document type.major_type: The major document type.country_code: The ISO country code.country: The country name.region: The administrative region name.language: The document language.date: The document date.report_number: The report number.project_id: The ID of the associated project, orNAif there is none.url: The document URL.pdf_url: The PDF URL.abstract: The abstract.
Examples
# \donttest{
# project appraisal documents for Brazil published in 2024
wb_document(
country = "BR",
type = "Project Appraisal Document",
start_date = "2024-01-01",
end_date = "2024-12-31"
)
#> id
#> 1 34409107
#> 2 34380251
#> 3 34312179
#> 4 34310682
#> 5 34288986
#> 6 34280782
#> 7 34266848
#> 8 34240697
#> title
#> 1 Brazil - Bahia Sustainable Rural Development Project
#> 2 Brazil - State of Bahia Proactive, Safe, and Resilient Road Asset Management Program Project
#> 3 Brazil - Pernambuco Rural Water and Sanitation Project
#> 4 Brazil - Espirito Santo Digital Acceleration Project
#> 5 Brazil - Integrated Sustainable Mobility Project in the Foz do Rio Itajaí Region
#> 6 Brazil - Sustainable Human Development Project in the State of Pará
#> 7 Brazil - Second Piauí Pillars of Growth and Social Inclusion Project
#> 8 Brazil - Mato Grosso Sustainable Development of Family Farming Project
#> type major_type country_code country
#> 1 Project Appraisal Document Project Documents BR Brazil
#> 2 Project Appraisal Document Project Documents BR Brazil
#> 3 Project Appraisal Document Project Documents BR Brazil
#> 4 Project Appraisal Document Project Documents BR Brazil
#> 5 Project Appraisal Document Project Documents BR Brazil
#> 6 Project Appraisal Document Project Documents BR Brazil
#> 7 Project Appraisal Document Project Documents BR Brazil
#> 8 Project Appraisal Document Project Documents BR Brazil
#> region language date report_number project_id
#> 1 Latin America and Caribbean English 2024-10-11 PAD00054 P180429
#> 2 Latin America and Caribbean English 2024-08-17 PAD00056 P180555
#> 3 Latin America and Caribbean English 2024-04-26 PAD00074 P180430
#> 4 Latin America and Caribbean English 2024-04-25 PAD00141 P180462
#> 5 Latin America and Caribbean English 2024-03-22 PAD5121 P178557
#> 6 Latin America and Caribbean English 2024-03-07 PAD00127 P500524
#> 7 Latin America and Caribbean English 2024-02-19 PAD5325 P177474
#> 8 Latin America and Caribbean English 2024-01-12 PAD5150 P175723
#> url
#> 1 http://documents.worldbank.org/curated/en/099102124100530964
#> 2 http://documents.worldbank.org/curated/en/099082124173024196
#> 3 http://documents.worldbank.org/curated/en/099043024103021754
#> 4 http://documents.worldbank.org/curated/en/099043024091034075
#> 5 http://documents.worldbank.org/curated/en/099032624162515430
#> 6 http://documents.worldbank.org/curated/en/099031124173545505
#> 7 http://documents.worldbank.org/curated/en/099022624152531040
#> 8 http://documents.worldbank.org/curated/en/099011724100531821
#> pdf_url
#> 1 https://documents.worldbank.org/curated/en/099102124100530964/pdf/BOSIB-9c8aa18f-cb4b-4a65-ab9e-208329249066.pdf
#> 2 https://documents.worldbank.org/curated/en/099082124173024196/pdf/BOSIB-8d3c5a35-f193-43ea-a897-177991415933.pdf
#> 3 http://documents.worldbank.org/curated/en/099043024103021754/pdf/BOSIB1053111dd04d1a4a7124c2c07cd3c4.pdf
#> 4 http://documents.worldbank.org/curated/en/099043024091034075/pdf/BOSIB13b9c3ff30fd1aa751c1dfdb5cfade.pdf
#> 5 https://documents.worldbank.org/curated/en/099032624162515430/pdf/BOSIB-60d57288-4e09-4519-ae6c-ffdc0037e0b1.pdf
#> 6 https://documents.worldbank.org/curated/en/099031124173545505/pdf/BOSIB-ade47866-a4cd-44a5-a87a-25b991994fd0.pdf
#> 7 https://documents.worldbank.org/curated/en/099022624152531040/pdf/BOSIB-fad1397d-8f2f-415f-be8e-0c626b505b3f.pdf
#> 8 http://documents.worldbank.org/curated/en/099011724100531821/pdf/BOSIB17d9a3771077192e9153d157697ada.pdf
#> abstract
#> 1 The development objective of the Bahia Sustainable Rural Development Project for Brazil is to enhance resilience of family farmers in targeted states. The project comprises of five components. The first component, increasing agricultural productivity, access to markets, and resilience to shocks will finance technical studies, technical assistance (TA), and matching grants to co-finance business and the development plans of Producer Organizations (POs) and to support investments in climate-smart agriculture (CSA). It consists of following sub-components: (i) development of business plans and strengthening capacities of POs and family farmers; (ii) implementation of business and ethno-development plans; and (iii) improving access to complementary agricultural public policies. The second component, supplying safe drinking water services to rural communities will fund water infrastructure to improve food and nutrition security of low-income rural households through the expansion of access to drinking water services from rural dwellers, its main objective will be to support the Bahia’s efforts to develop a rural water state policy and bringing about institutional changes in the water sector to mainstream a strategy for managing rural water services. It consists of following sub-components: (i) strengthening and consolidating the multi-community management model for rural water supply services; and (ii) investments in rural water infrastructure and monitoring of service delivery. The third component, designing and scaling innovative solutions for agrifood production and commercialization will finance the scaling of innovations that can have a positive impact on the long-term sustainability of the interventions on POs (Component 1). It consists of following sub-component: (i) scaling innovations to improve productivity and access to markets. The fourth component, contingency emergency response component (CERC) is a mechanism for Borrowers (Bahia) to access funds rapidly to respond to an eligible crisis or disasters and health emergency. The fifth component, project management and institutional development will support the participation of the Project Management Unit (PMU) in the multiphase programmatic approach (MPA) coordination, learning and, monitoring efforts.
#> 2 The development objective of the State of Bahia Proactive, Safe, and Resilient Road Asset Management Program Project for Brazil is to improve access to sustainable, safe, and resilient transport in selected states of Brazil. The project comprises of four components. The first component, proactive maintenance based on a long-term (8 to 25 years) performance-based contract for rehabilitation and road maintenance (CREMA) model using performance-based contract (PBCs) consists of following sub-components: (i) proactive maintenance CREMA- design-build-maintain (DBM): long-term performance-based road management contracts for safe and resilient state or federal road corridors; and (ii) proactive maintenance CREMA- public-private partnership (PPP): long-term performance-based contracts using the PPP modality for selected safe and resilient state roads. The second component is institutional strengthening, covering three sets of activities: proactive, safe, and resilient road asset management; green mobility and logistics; and social inclusion and gender. The third component, safe and resilient improvements of road infrastructure will focus on promoting road safety in areas where interactions between vehicles and pedestrians and cyclists are frequent, and on climate resilient and all-season access in selected areas identified by the participant states. It consists of following sub-components: (i) construction of bypasses in areas prone to flooding and logistical bottlenecks along selected state road corridors; (ii) safe active mobility infrastructure in selected urbanized areas; and (iii) improvement to all-season access to transport in rural areas. The fourth component, project management will support management and coordination of the different phases of the Program.
#> 3 The objective of the Pernambuco Rural Water and Sanitation Project for Brazil is to increase access to sustainable, safely managed drinking water supply and improved sanitation in selected rural communities and to build the Borrower’s capacity to reach universal RWSS services. There are three components to the project. The first component being increase access to climate-resilient, safely managed RWS and improved sanitation. This component aims at increasing rural population’s access to safely managed drinking water supply resilient to water scarcity, droughts and floods, and improved on-site sanitation solutions, thereby contributing to the State universal WSS access goal and increasing the rural population’s resilience to climate change exacerbated water scarcity, droughts, and floods. This component includes three subcomponents: increase access to safely managed RWS and improved on-site sanitation solutions with climate-resilient designs, improve climate-resilience of water sources, and innovate with climate-resilient, safely managed RWSS pilot solutions for universal access. The second component is to build the Borrower’s capacity to reach universal and climate resilient RWSS access and sustainably managed RWS systems and their water sources. This component includes two subcomponents: build the Borrower’s capacity to reach universal RWSS access and sustainably managed RWS systems, and strengthen the resilience of the Borrower’s RWS systems’ water sources under climate risks. Finally, the third component is the project management. This component strengthens the Borrower’s capacity to carry out the Project through, inter alia, (a) the setting up and operationalization of the PMU, in particular with respect to (i) the coordination, management and administration of Project’s activities; (ii) the hiring of staff and of key consultancy firms; (iii) the delivery of training; (iv) the provision of equipment; (v) the carrying out of financial management and procurement activities; (vi) the carrying out of monitoring, supervision and project evaluation activities; (vii) the carrying out of the environmental, social and dam safety aspects of the Project, as well as the implementation of a grievance redress mechanism; (viii) the carrying out of technical and financial audits; and (ix) the carrying out of citizen and gender engagements, and communication and outreach activities; and (b) the strengthening of internal controls of the Borrower through the provision of support to the State Comptroller General.
#> 4 The objective of the Espirito Santo Digital Acceleration Project for Brazil is to strengthen digital infrastructure resilience, to modernize emergency management, and to improve digital public infrastructure in the State of Espirito Santo. There are four components to the project, the first component being resilient data infrastructure and digital skills. This component includes four subcomponents: Technical assistance, support to development of a resilient data center, digital skills, and digital projects acceleration platform. The second component is the strengthening of digital public infrastructure. This component includes three subcomponents: enhancing software solutions to improve service delivery, hardware to support the operation of the services portal infrastructure, and Design and implementation of software applications and consulting services according to GoES’s needs. The third component is the modernize emergency management system. This component includes three subcomponents: centralized emergency response technical integration plan and feasibility studies, Design, build and operationalization of the Integrated Center for Social Defense (CIDES), and development and integration of all the systems and procedures for the management of emergency calls. Finally, the fourth component is the project management. This component will provide support for the management and implementation of the project, including: (a) project coordination; (b) procurement and financial management (FM); (c) implementation of E&S risk management measures; (d) Monitoring and Evaluation (M&E); (e) support of training and advisory and audit services needed; and (f) public information; citizen engagement, and communication. Special attention will be devoted to promoting equal participation of women in all decision-making bodies under the project and contributing to tackling barriers to recruitment, retention, and promotion.
#> 5 The Development objective of the Brazil - Integrated Sustainable Mobility Project in the Foz do Rio Itajaí Region is to improve accessibility and mobility in an inclusive and low-emission\nmanner in selected areas of the Foz do Rio Itajaí Region. The Project will support four main components. The components will incorporate several activities aiming at improving accessibility by improving public and nonmotorized transport infrastructure, reducing emissions and ensuring affordability and inclusion in the design and operation. In the same way, their design will follow the Road Safety Vision Zero Strategy, universal accessibility, and climate resilience features to ensure that all components of the Project are safe and accessible for all, while reducing climate-related disaster risks. The Project includes drainage works and a control center for the BRT operations, which will integrate disaster-risk management. Further, the Project is being prepared in a participatory manner, with the client reaching out to the population of the Region to enhance expected outcomes. In addition, the Project will focus on economically vulnerable groups (women, people with disabilities, children and young, refugees/immigrants, elderly, long-term unemployed, and so on) as the main beneficiaries and will aim to reduce the mobility gap between men and women by providing women with better access to opportunities. Finally, the total estimated costs for each component include preliminary values of potential private investment. A detailed description of each component and a financing table are presented in Annex 2.
#> 6 The development objective of the Brazil - Sustainable Human Development Project in the State of Pará is to (i) improve social protection services and food security, (ii) improve learning, and (iii) promote forest conservation in the State of Pará, prioritizing the Marajó. The project will consist of the following components: Component 1: Improving social protection services and food security (US$125 million, of which US$100 million IBRD); Component 2: Improving Learning (US$125 million, of which US$100 million IBRD); Component 3: Standing Forests (US$90 million, of which US$70 million IBRD); and Component 4: Project Management and COP 30 (US$10 million IBRD).
#> 7 The development objective of the Brazil - Second Piauí Pillars of Growth and Social Inclusion Project is to increase land tenure security, the adoption of sustainable natural resources management practices, and ClimateSmart Agriculture practices among target beneficiaries in the State of Piauí; and in case of an Eligible Crisis or Emergency, respond promptly and effectively to it. The project will consist of the following components: Component 1 – Land Tenure Regularization (Total cost US$20.08 million, of which IBRD loan US$15.85 million); Component 2 – Environmental Management and Geospatial Information Management (Total Cost US$14.00 million; of which IBRD loan US$12.24 million); Component 3. Climate-smart Rural Development (Total Cost US$25.28 million; of which IBRD loan US$18.05 million and beneficiaries US$0.82 million); Component 4. Project Management (Total Cost US$3.96 million; of which IBRD loan US$3.86 million); and Component 5. Emergency Response (US$0).
#> 8 The development objective of the Mato Grosso Sustainable Development of Family Farming Project for Brazil is to improve the access to markets, climate resilience, and land and environmental management of selected family farmers in the State of Mato Grosso and in case of an eligible crisis or emergency, respond promptly and effectively to it. The project comprises of four components. The first component, climate-smart economic inclusion will support the climate resilience of family farmers in Mato Grosso and improve their market linkages to sustain resilient production models over time. It consists of following sub-components: (i) pre-investments for the preparation of climate-smart agriculture (CSA) family farming business plans; and (ii) productive investments in CSA family farming business plans. The second component, improved land and environmental management will increase the generation of environmental benefits, including for climate resilience and mitigation, of family farming in Mato Grosso. It consists of following sub-components: (i) support for land and environmental regularization; and (ii) prevention and control of forest fire and deforestation in family farming areas. The third component, project management and coordination objectives are to provide the Project Management Unit (PMU) with the conditions and information necessary for the effective management and coordination of the project. The fourth component, contingency emergency response component (CERC) will provide for an immediate response to an eligible crisis or emergency, as needed.
# all documents belonging to a project
wb_document(project = "P180429")
#> id
#> 1 40127791
#> 2 40123773
#> 3 40122790
#> 4 40121908
#> 5 40117840
#> 6 40117671
#> 7 40116452
#> 8 40111110
#> 9 40109790
#> 10 40101018
#> 11 40092797
#> 12 40090138
#> 13 40088879
#> 14 40088922
#> 15 40086395
#> 16 40077275
#> 17 40064331
#> 18 40061283
#> 19 40055169
#> 20 40055173
#> 21 40054285
#> 22 40055174
#> 23 40039991
#> 24 40038091
#> 25 40037598
#> 26 40033982
#> 27 40034000
#> 28 40030456
#> 29 40029223
#> 30 34457006
#> 31 34450098
#> 32 34420388
#> 33 34420389
#> 34 34409107
#> 35 34382182
#> 36 34382183
#> 37 34321639
#> 38 34319227
#> 39 34308578
#> 40 34308577
#> 41 34308576
#> 42 34306803
#> 43 34402700
#> 44 34173758
#> 45 34078614
#> title
#> 1 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 2 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 3 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 4 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 5 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 6 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 7 Disclosable Version of the ISR - Bahia Sustainable Rural Development Project - P180429 - Sequence No : 4
#> 8 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 9 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 10 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 11 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 12 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 13 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 14 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 15 Disclosable Version of the ISR - Bahia Sustainable Rural Development Project - P180429 - Sequence No : 3
#> 16 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 17 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 18 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 19 Official Documents- Loan Agreement for Loan 9738-BR.pdf
#> 20 Official Documents- Guarantee Agreement for Loan 9738-BR.pdf
#> 21 Environmental and Social Commitment Plan (ESCP) Bahia Sustainable Rural Development Project (P180429)
#> 22 Official Documents- Disbursement and Financial Information Letter for Loan 9738-BR.pdf
#> 23 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 24 Disclosable Version of the ISR - Bahia Sustainable Rural Development Project - P180429 - Sequence No : 2
#> 25 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 26 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 27 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 28 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 29 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 30 Disclosable Version of the ISR - Bahia Sustainable Rural Development Project - P180429 - Sequence No : 1
#> 31 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 32 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 33 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 34 Brazil - Bahia Sustainable Rural Development Project
#> 35 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 36 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 37 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 38 Brazil - LATIN AMERICA AND CARIBBEAN- P180429- Bahia Sustainable Rural Development Project - Procurement Plan
#> 39 Appraisal Environmental and Social Review Summary (ESRS) - Bahia Sustainable Rural Development Project - P180429
#> 40 Environmental and Social Commitment Plan (ESCP) - Bahia Sustainable Rural Development Project - P180429
#> 41 Stakeholder Engagement Plan (SEP) - Bahia Sustainable Rural Development Project - P180429
#> 42 Revised Environmental and Social Impact Assessment Bahia Sustainable Rural Development Project (P180429)
#> 43 Brazil - Bahia Sustainable Rural Development Project
#> 44 Concept Environmental and Social Review Summary (ESRS) - Bahia Sustainable Rural Development Project - Phase 2 - P180429
#> 45 Concept Project Information Document (PID) - Bahia Sustainable Rural Development Project - Phase 2 - P180429
#> type
#> 1 Procurement Plan
#> 2 Procurement Plan
#> 3 Procurement Plan
#> 4 Procurement Plan
#> 5 Procurement Plan
#> 6 Procurement Plan
#> 7 Implementation Status and Results Report
#> 8 Procurement Plan
#> 9 Procurement Plan
#> 10 Procurement Plan
#> 11 Procurement Plan
#> 12 Procurement Plan
#> 13 Procurement Plan
#> 14 Procurement Plan
#> 15 Implementation Status and Results Report
#> 16 Procurement Plan
#> 17 Procurement Plan
#> 18 Procurement Plan
#> 19 Loan Agreement
#> 20 Guarantee Agreement
#> 21 Environmental and Social Commitment Plan
#> 22 Disbursement Letter
#> 23 Procurement Plan
#> 24 Implementation Status and Results Report
#> 25 Procurement Plan
#> 26 Procurement Plan
#> 27 Procurement Plan
#> 28 Procurement Plan
#> 29 Procurement Plan
#> 30 Implementation Status and Results Report
#> 31 Procurement Plan
#> 32 Procurement Plan
#> 33 Procurement Plan
#> 34 Project Appraisal Document
#> 35 Procurement Plan
#> 36 Procurement Plan
#> 37 Procurement Plan
#> 38 Procurement Plan
#> 39 Environmental and Social Review Summary
#> 40 Environmental and Social Commitment Plan
#> 41 Stakeholder Engagement Plan
#> 42 Environmental and Social Assessment; Environmental Assessment; Social Assessment
#> 43 Project Information Document
#> 44 Environmental and Social Review Summary
#> 45 Project Information Document
#> major_type country_code country region
#> 1 Project Documents BR Brazil Latin America and Caribbean
#> 2 Project Documents BR Brazil Latin America and Caribbean
#> 3 Project Documents BR Brazil Latin America and Caribbean
#> 4 Project Documents BR Brazil Latin America and Caribbean
#> 5 Project Documents BR Brazil Latin America and Caribbean
#> 6 Project Documents BR Brazil Latin America and Caribbean
#> 7 Project Documents BR Brazil Latin America and Caribbean
#> 8 Project Documents BR Brazil Latin America and Caribbean
#> 9 Project Documents BR Brazil Latin America and Caribbean
#> 10 Project Documents BR Brazil Latin America and Caribbean
#> 11 Project Documents BR Brazil Latin America and Caribbean
#> 12 Project Documents BR Brazil Latin America and Caribbean
#> 13 Project Documents BR Brazil Latin America and Caribbean
#> 14 Project Documents BR Brazil Latin America and Caribbean
#> 15 Project Documents BR Brazil Latin America and Caribbean
#> 16 Project Documents BR Brazil Latin America and Caribbean
#> 17 Project Documents BR Brazil Latin America and Caribbean
#> 18 Project Documents BR Brazil Latin America and Caribbean
#> 19 Project Documents BR Brazil Latin America and Caribbean
#> 20 Project Documents BR Brazil Latin America and Caribbean
#> 21 Project Documents BR Brazil Latin America and Caribbean
#> 22 Project Documents BR Brazil Latin America and Caribbean
#> 23 Project Documents BR Brazil Latin America and Caribbean
#> 24 Project Documents BR Brazil Latin America and Caribbean
#> 25 Project Documents BR Brazil Latin America and Caribbean
#> 26 Project Documents BR Brazil Latin America and Caribbean
#> 27 Project Documents BR Brazil Latin America and Caribbean
#> 28 Project Documents BR Brazil Latin America and Caribbean
#> 29 Project Documents BR Brazil Latin America and Caribbean
#> 30 Project Documents BR Brazil Latin America and Caribbean
#> 31 Project Documents BR Brazil Latin America and Caribbean
#> 32 Project Documents BR Brazil Latin America and Caribbean
#> 33 Project Documents BR Brazil Latin America and Caribbean
#> 34 Project Documents BR Brazil Latin America and Caribbean
#> 35 Project Documents BR Brazil Latin America and Caribbean
#> 36 Project Documents BR Brazil Latin America and Caribbean
#> 37 Project Documents BR Brazil Latin America and Caribbean
#> 38 Project Documents BR Brazil Latin America and Caribbean
#> 39 Project Documents BR Brazil Latin America and Caribbean
#> 40 Project Documents BR Brazil Latin America and Caribbean
#> 41 Project Documents BR Brazil Latin America and Caribbean
#> 42 Project Documents BR Brazil Latin America and Caribbean
#> 43 Project Documents BR Brazil Latin America and Caribbean
#> 44 Project Documents BR Brazil Latin America and Caribbean
#> 45 Project Documents BR Brazil Latin America and Caribbean
#> language date report_number project_id
#> 1 English 2026-09-16 <NA> P180429
#> 2 English 2026-08-21 <NA> P180429
#> 3 English 2026-08-17 <NA> P180429
#> 4 English 2026-08-11 <NA> P180429
#> 5 English 2026-07-20 <NA> P180429
#> 6 English 2026-07-17 <NA> P180429
#> 7 English 2026-07-11 ISR08149 P180429
#> 8 English 2026-06-22 <NA> P180429
#> 9 English 2026-06-17 <NA> P180429
#> 10 English 2026-05-04 <NA> P180429
#> 11 English 2026-03-20 <NA> P180429
#> 12 English 2026-03-05 <NA> P180429
#> 13 English 2026-02-26 <NA> P180429
#> 14 English 2026-02-26 <NA> P180429
#> 15 English 2026-02-12 ISR06930 P180429
#> 16 English 2025-12-18 <NA> P180429
#> 17 English 2025-10-24 <NA> P180429
#> 18 English 2025-10-21 <NA> P180429
#> 19 English 2025-10-10 <NA> P180429
#> 20 English 2025-10-10 <NA> P180429
#> 21 English 2025-10-10 <NA> P180429
#> 22 English 2025-10-10 <NA> P180429
#> 23 English 2025-08-27 <NA> P180429
#> 24 English 2025-08-14 ISR04942 P180429
#> 25 English 2025-08-12 <NA> P180429
#> 26 English 2025-07-24 <NA> P180429
#> 27 English 2025-07-24 <NA> P180429
#> 28 English 2025-07-17 <NA> P180429
#> 29 English 2025-07-10 <NA> P180429
#> 30 English 2025-02-17 ISR03187 P180429
#> 31 English 2025-01-28 STEP108212 P180429
#> 32 English 2024-11-11 STEP105095 P180429
#> 33 English 2024-11-11 STEP105094 P180429
#> 34 English 2024-10-11 PAD00054 P180429
#> 35 English 2024-08-27 STEP101542 P180429
#> 36 English 2024-08-27 STEP101543 P180429
#> 37 English 2024-05-20 STEP97111 P180429
#> 38 English 2024-05-16 STEP96942 P180429
#> 39 English 2024-04-25 ESRSA03285 P180429
#> 40 English 2024-04-25 <NA> P180429
#> 41 English 2024-04-25 <NA> P180429
#> 42 Portuguese 2024-04-23 <NA> P180429
#> 43 English 2024-04-19 PIDIA00698 P180429
#> 44 English 2023-10-02 ESRSC03692 P180429
#> 45 English 2023-06-12 PIDC35569 P180429
#> url
#> 1 http://documents.worldbank.org/curated/en/099091626154016492
#> 2 http://documents.worldbank.org/curated/en/099082126145525027
#> 3 http://documents.worldbank.org/curated/en/099081726101040327
#> 4 http://documents.worldbank.org/curated/en/099081126181012675
#> 5 http://documents.worldbank.org/curated/en/099072026092022946
#> 6 http://documents.worldbank.org/curated/en/099071726160039079
#> 7 http://documents.worldbank.org/curated/en/099071026220592992
#> 8 http://documents.worldbank.org/curated/en/099062226100034290
#> 9 http://documents.worldbank.org/curated/en/099061626200538640
#> 10 http://documents.worldbank.org/curated/en/099050426152020899
#> 11 http://documents.worldbank.org/curated/en/099031926224040338
#> 12 http://documents.worldbank.org/curated/en/099030526093089201
#> 13 http://documents.worldbank.org/curated/en/099022626090011982
#> 14 http://documents.worldbank.org/curated/en/099022626124530714
#> 15 http://documents.worldbank.org/curated/en/099021226120039963
#> 16 http://documents.worldbank.org/curated/en/099121825142040072
#> 17 http://documents.worldbank.org/curated/en/099102425102526306
#> 18 http://documents.worldbank.org/curated/en/099102125085039398
#> 19 http://documents.worldbank.org/curated/en/099101425084529808
#> 20 http://documents.worldbank.org/curated/en/099101425085038753
#> 21 http://documents.worldbank.org/curated/en/099101025171518571
#> 22 http://documents.worldbank.org/curated/en/099101425085021147
#> 23 http://documents.worldbank.org/curated/en/099082725150515121
#> 24 http://documents.worldbank.org/curated/en/099081425152038720
#> 25 http://documents.worldbank.org/curated/en/099081225110512583
#> 26 http://documents.worldbank.org/curated/en/099072425150031499
#> 27 http://documents.worldbank.org/curated/en/099072425170025190
#> 28 http://documents.worldbank.org/curated/en/099071725085522508
#> 29 http://documents.worldbank.org/curated/en/099071025091532001
#> 30 http://documents.worldbank.org/curated/en/099021725072518876
#> 31 http://documents.worldbank.org/curated/en/099012725191536286
#> 32 http://documents.worldbank.org/curated/en/099111124120510033
#> 33 http://documents.worldbank.org/curated/en/099111124120067669
#> 34 http://documents.worldbank.org/curated/en/099102124100530964
#> 35 http://documents.worldbank.org/curated/en/099082724163512954
#> 36 http://documents.worldbank.org/curated/en/099082724163588323
#> 37 http://documents.worldbank.org/curated/en/099052024161017643
#> 38 http://documents.worldbank.org/curated/en/099051624092540072
#> 39 http://documents.worldbank.org/curated/en/099042524173023798
#> 40 http://documents.worldbank.org/curated/en/099042524172515208
#> 41 http://documents.worldbank.org/curated/en/099042524172532795
#> 42 http://documents.worldbank.org/curated/en/099042324123035354
#> 43 http://documents.worldbank.org/curated/en/099722210102417323
#> 44 http://documents.worldbank.org/curated/en/099100223155525902
#> 45 http://documents.worldbank.org/curated/en/099061223162019669
#> pdf_url
#> 1 https://documents.worldbank.org/curated/en/099091626154016492/pdf/P180429-c4c8c9e8-6bc6-4db9-9535-2d7b57a1f382.pdf
#> 2 https://documents.worldbank.org/curated/en/099082126145525027/pdf/P180429-a8e4c1ab-7cdf-4930-b976-a6a378764894.pdf
#> 3 https://documents.worldbank.org/curated/en/099081726101040327/pdf/P180429-09f45a51-4e0f-413b-9081-ca0654d5e723.pdf
#> 4 https://documents.worldbank.org/curated/en/099081126181012675/pdf/P180429-db31c711-0b8a-4848-9b48-18342d8c500b.pdf
#> 5 https://documents.worldbank.org/curated/en/099072026092022946/pdf/P180429-6111ba8b-0542-4eb5-baa1-46a6b09af0e7.pdf
#> 6 https://documents.worldbank.org/curated/en/099071726160039079/pdf/P180429-3b942d65-0820-4d76-8465-3d6e2d94081f.pdf
#> 7 https://documents.worldbank.org/curated/en/099071026220592992/pdf/P180429-f4bd206b-0b5e-4382-8e06-d9bc61295289.pdf
#> 8 https://documents.worldbank.org/curated/en/099062226100034290/pdf/P180429-e64f5e60-35c4-4ed6-b779-41fe615c1041.pdf
#> 9 https://documents.worldbank.org/curated/en/099061626200538640/pdf/P180429-e182b9eb-8dc6-4869-82ae-18be69069e79.pdf
#> 10 https://documents.worldbank.org/curated/en/099050426152020899/pdf/P180429-c28c8d31-f667-41c1-ba28-096b33339e33.pdf
#> 11 https://documents.worldbank.org/curated/en/099031926224040338/pdf/P180429-642a8ec3-9623-4778-8e55-8aee46cf8e2d.pdf
#> 12 https://documents.worldbank.org/curated/en/099030526093089201/pdf/P180429-c6e9cb20-e8aa-40df-add7-3c254a2ab934.pdf
#> 13 https://documents.worldbank.org/curated/en/099022626090011982/pdf/P180429-717b7661-b9fa-4780-9b68-85774d8214c9.pdf
#> 14 https://documents.worldbank.org/curated/en/099022626124530714/pdf/P180429-089cb98f-8cf9-446b-bae3-11a0e0e392b2.pdf
#> 15 https://documents.worldbank.org/curated/en/099021226120039963/pdf/P180429-68724d0c-8d4e-4cbc-83f1-b1ce413064a9.pdf
#> 16 https://documents.worldbank.org/curated/en/099121825142040072/pdf/P180429-65d89127-f6ce-4e56-a6b7-8b2a7cc22ded.pdf
#> 17 https://documents.worldbank.org/curated/en/099102425102526306/pdf/P180429-172aac50-2e38-4daa-a6ca-f8e85c7a58ec.pdf
#> 18 https://documents.worldbank.org/curated/en/099102125085039398/pdf/P180429-82ca9736-1d37-4af9-a278-05381bde1921.pdf
#> 19 https://documents.worldbank.org/curated/en/099101425084529808/pdf/P180429-78ae8360-e7d1-4e51-9dc4-c41870a0cf0a.pdf
#> 20 https://documents.worldbank.org/curated/en/099101425085038753/pdf/P180429-3608e73a-1ed7-4067-93e9-37a1b62ac841.pdf
#> 21 https://documents.worldbank.org/curated/en/099101025171518571/pdf/P180429-2d2f4c1b-6baf-4dbb-873f-fdf118497b99.pdf
#> 22 https://documents.worldbank.org/curated/en/099101425085021147/pdf/P180429-f816ab84-be0f-48e0-9278-8a20c85a23b9.pdf
#> 23 https://documents.worldbank.org/curated/en/099082725150515121/pdf/P180429-ae94e1d5-0fe3-46a1-bc68-2fb1ae1e2ef3.pdf
#> 24 https://documents.worldbank.org/curated/en/099081425152038720/pdf/P180429-4580715f-4886-45a1-a4f5-da41e46fac77.pdf
#> 25 https://documents.worldbank.org/curated/en/099081225110512583/pdf/P180429-ad591625-e4bb-46e9-8ccc-c103a6772d03.pdf
#> 26 https://documents.worldbank.org/curated/en/099072425150031499/pdf/P180429-cda2d978-340e-4e8b-bb69-80ced2278669.pdf
#> 27 https://documents.worldbank.org/curated/en/099072425170025190/pdf/P180429-ac1b6d43-689e-4e91-8848-1db55c32d42b.pdf
#> 28 https://documents.worldbank.org/curated/en/099071725085522508/pdf/P180429-2db93244-de07-4797-9f09-93f5b61382bd.pdf
#> 29 https://documents.worldbank.org/curated/en/099071025091532001/pdf/P180429-ffd3920a-b6c7-43f8-ba93-eef2f5f65797.pdf
#> 30 https://documents.worldbank.org/curated/en/099021725072518876/pdf/P180429-11df8844-3b96-4157-8335-57433a521343.pdf
#> 31 https://documents.worldbank.org/curated/en/099012725191536286/pdf/P180429-a6978926-7664-48b8-8841-5c9018105c47.pdf
#> 32 https://documents.worldbank.org/curated/en/099111124120510033/pdf/P180429-6ca8b4ec-fb01-4cba-9f67-b46a6e8fc2b1.pdf
#> 33 https://documents.worldbank.org/curated/en/099111124120067669/pdf/P180429-4abf7ab0-823d-4464-8639-f4d7fbd42fcf.pdf
#> 34 https://documents.worldbank.org/curated/en/099102124100530964/pdf/BOSIB-9c8aa18f-cb4b-4a65-ab9e-208329249066.pdf
#> 35 https://documents.worldbank.org/curated/en/099082724163512954/pdf/P180429-b6d12dc4-63ed-49f9-9994-22296ecc7990.pdf
#> 36 https://documents.worldbank.org/curated/en/099082724163588323/pdf/P180429-9f89cdb2-45ea-43da-aa04-29009c946ecd.pdf
#> 37 http://documents.worldbank.org/curated/en/099052024161017643/pdf/P180429105cc6d0e9184361d74250d9cb6f.pdf
#> 38 http://documents.worldbank.org/curated/en/099051624092540072/pdf/P1804291a132cb06f1bf641782e1a92972b.pdf
#> 39 https://documents.worldbank.org/curated/en/099042524173023798/pdf/P180429-1d48fee0-23da-4aac-a871-f469d7cbed3a.pdf
#> 40 http://documents.worldbank.org/curated/en/099042524172515208/pdf/P1804291d63db20518dba154b4b0b2f037.pdf
#> 41 http://documents.worldbank.org/curated/en/099042524172532795/pdf/P18042918be5fc031953916504ca1c0a43.pdf
#> 42 http://documents.worldbank.org/curated/en/099042324123035354/pdf/P1804291cd02f40418d5314ff0d3532d76.pdf
#> 43 https://documents.worldbank.org/curated/en/099722210102417323/pdf/IDU-89129d52-de9f-4948-9da6-158954a709e1.pdf
#> 44 http://documents.worldbank.org/curated/en/099100223155525902/pdf/P1804290a85f9b0c70b6ca0c313f67b9676.pdf
#> 45 http://documents.worldbank.org/curated/en/099061223162019669/pdf/P1804290e85ca50b0a55e09a3c27f757f4.pdf
#> abstract
#> 1 <NA>
#> 2 <NA>
#> 3 <NA>
#> 4 <NA>
#> 5 <NA>
#> 6 <NA>
#> 7 <NA>
#> 8 <NA>
#> 9 <NA>
#> 10 <NA>
#> 11 <NA>
#> 12 <NA>
#> 13 <NA>
#> 14 <NA>
#> 15 <NA>
#> 16 <NA>
#> 17 <NA>
#> 18 <NA>
#> 19 <NA>
#> 20 <NA>
#> 21 <NA>
#> 22 <NA>
#> 23 <NA>
#> 24 <NA>
#> 25 <NA>
#> 26 <NA>
#> 27 <NA>
#> 28 <NA>
#> 29 <NA>
#> 30 <NA>
#> 31 <NA>
#> 32 <NA>
#> 33 <NA>
#> 34 The development objective of the Bahia Sustainable Rural Development Project for Brazil is to enhance resilience of family farmers in targeted states. The project comprises of five components. The first component, increasing agricultural productivity, access to markets, and resilience to shocks will finance technical studies, technical assistance (TA), and matching grants to co-finance business and the development plans of Producer Organizations (POs) and to support investments in climate-smart agriculture (CSA). It consists of following sub-components: (i) development of business plans and strengthening capacities of POs and family farmers; (ii) implementation of business and ethno-development plans; and (iii) improving access to complementary agricultural public policies. The second component, supplying safe drinking water services to rural communities will fund water infrastructure to improve food and nutrition security of low-income rural households through the expansion of access to drinking water services from rural dwellers, its main objective will be to support the Bahia’s efforts to develop a rural water state policy and bringing about institutional changes in the water sector to mainstream a strategy for managing rural water services. It consists of following sub-components: (i) strengthening and consolidating the multi-community management model for rural water supply services; and (ii) investments in rural water infrastructure and monitoring of service delivery. The third component, designing and scaling innovative solutions for agrifood production and commercialization will finance the scaling of innovations that can have a positive impact on the long-term sustainability of the interventions on POs (Component 1). It consists of following sub-component: (i) scaling innovations to improve productivity and access to markets. The fourth component, contingency emergency response component (CERC) is a mechanism for Borrowers (Bahia) to access funds rapidly to respond to an eligible crisis or disasters and health emergency. The fifth component, project management and institutional development will support the participation of the Project Management Unit (PMU) in the multiphase programmatic approach (MPA) coordination, learning and, monitoring efforts.
#> 35 <NA>
#> 36 <NA>
#> 37 <NA>
#> 38 <NA>
#> 39 <NA>
#> 40 <NA>
#> 41 <NA>
#> 42 <NA>
#> 43 <NA>
#> 44 <NA>
#> 45 <NA>
# }