pip_cp: Return country profile data

View source: R/pip.R

pip_cpR Documentation

Return country profile data

Description

Return country profile data

Usage

pip_cp(
  country = NULL,
  povline = 2.15,
  release_version = NULL,
  ppp_version = NULL,
  version = NULL
)

Arguments

country

(NULL | character())
Countries for which statistics are to be computed, specified as ISO3 codes. Default NULL.

povline

(numeric(1))
Poverty line to be used to compute poverty measures. Poverty lines are only accepted up to 3 decimals. Default 2.15.

release_version

(NULL | character(1))
Version of the data release in YYYYMMDD format. Default NULL.

ppp_version

(NULL | character(1) | numeric(1))
Version of the data. Default NULL.

version

(NULL | character(1))
Version of the data. Default NULL.

Value

A data.frame() with country profile statistics including headcount ratios, inequality measures, and demographic breakdowns.

https://pip.worldbank.org/api

See Also

Other poverty and inequality statistics: pip_aux(), pip_citation(), pip_data(), pip_group(), pip_health_check(), pip_info(), pip_valid_params(), pip_versions()

Examples



cp <- pip_cp("ZAF")
head(cp)



worldbank documentation built on March 15, 2026, 5:07 p.m.